#
# spec file for package libvpx
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         sover 8
Name:           libvpx
Version:        1.13.1
Release:        1.2
Summary:        VP8/VP9 codec library
License:        BSD-3-Clause AND GPL-2.0-or-later
Group:          Productivity/Multimedia/Other
URL:            https://www.webmproject.org/
Source0:        %{name}-%{version}.tar.xz
Source1000:     baselibs.conf
Patch2:         libvpx-configure-add-arch.patch
# only needed for test suite
BuildRequires:  gcc-c++
# Needed to be able to create pkgconfig() provides.
BuildRequires:  pkgconfig
BuildRequires:  yasm
# add curl and do not copy it in to get an updated test-data.sha1 file
#BuildRequires:  curl

%description
WebM is an open, royalty-free, media file format designed for the web.

WebM defines the file container structure, video and audio formats.
WebM files consist of video streams compressed with the VP8 video codec
and audio streams compressed with the Vorbis audio codec.
The WebM file structure is based on the Matroska container.

%package -n vpx-tools
Summary:        Utilies from the VP8/VP9 codec library
License:        BSD-3-Clause AND GPL-2.0-or-later
Group:          Productivity/Multimedia/Other

%description -n vpx-tools
This package contains utilities around the vp8 codec sdk.

WebM is an open, royalty-free, media file format designed for the web.

WebM defines the file container structure, video and audio formats.
WebM files consist of video streams compressed with the VP8 video codec
and audio streams compressed with the Vorbis audio codec.
The WebM file structure is based on the Matroska container.

%package -n %{name}%{sover}
Summary:        VP8/VP9 codec library
License:        BSD-3-Clause
Group:          System/Libraries

%description -n %{name}%{sover}
WebM is an open, royalty-free, media file format designed for the web.

WebM defines the file container structure, video and audio formats.
WebM files consist of video streams compressed with the VP8 video codec
and audio streams compressed with the Vorbis audio codec.
The WebM file structure is based on the Matroska container.

%package devel
Summary:        Development files for libvpx, a VP8/VP9 codec library
License:        BSD-3-Clause AND GPL-2.0-or-later
Group:          Development/Languages/C and C++
Requires:       %{name}%{sover} = %{version}

%description devel
Development headers and library

WebM is an open, royalty-free, media file format designed for the web.

WebM defines the file container structure, video and audio formats.
WebM files consist of video streams compressed with the VP8 video codec
and audio streams compressed with the Vorbis audio codec.
The WebM file structure is based on the Matroska container.

%prep
%autosetup -p1

%build
%define _lto_cflags %{nil}
%if 0%{?suse_version} < 1310
sed -i~ /ssse3/d configure
sed -i~ 's@ssse3@@' build/make/rtcd.pl
%endif
cd build
# It is only an emulation of autotools configure; the macro does not work
export CFLAGS="%{optflags} -O3"
export CXXFLAGS="%{optflags} -O3"
../configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir} \
    --enable-unit-tests \
    --enable-shared \
    --enable-pic \
    --disable-static \
    --enable-vp8 \
    --enable-vp9 \
    --enable-vp9-highbitdepth \
    --enable-postproc \
    --enable-multithread \
    --enable-pic \
%ifarch ppc64le
    --disable-vsx \
%endif
%ifarch armv5tel armv5el
    --target=armv5te-linux-gcc \
%endif
%ifarch armv7l armv7hl
    --target=armv7-linux-gcc \
    --enable-runtime-cpu-detect \
%endif
    --extra-cflags="-std=gnu99 -U_FORTIFY_SOURCE %{optflags}" \
    --extra-cxxflags="-U_FORTIFY_SOURCE %{optflags}" \
# size-limit to avoid CVE-2017-0641 DoS attacks. The limit is the
# 8K Fulldome resolution and should be enough for all current use cases
# bso#1056539
# the --size-limit switch is broken atm ...
echo '#define DECODE_WIDTH_LIMIT 8192'  >> vpx_config.h
echo '#define DECODE_HEIGHT_LIMIT 8192' >> vpx_config.h

%make_build verbose=yes GEN_EXAMPLES=

%install
cd build
make %{?_smp_mflags} verbose=yes GEN_EXAMPLES= DESTDIR=%{buildroot} install

%check
# needs network to download >400MB data
# make test

%ldconfig_scriptlets -n %{name}%{sover}

%files -n vpx-tools
%{_bindir}/*

%files -n %{name}%{sover}
%license LICENSE
%doc AUTHORS README CHANGELOG
%{_libdir}/libvpx.so.*

%files devel
%{_includedir}/vpx/
%{_libdir}/pkgconfig/vpx.pc
%{_libdir}/libvpx.so

%changelog
* Sun Oct  1 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.13.1:
  + Bug fixes: Fix to a crash related to VP9 encoding.
    https://crbug.com/1486441 (CVE-2023-5217)
- Drop CVE-2023-5217.patch: Fixed upstream.
* Thu Sep 28 2023 Adrian Schröter <adrian@suse.de>
- Fixing CVE-2023-5217 heap buffer overflow (boo#1215778)
  added CVE-2023-5217.patch
* Tue Feb 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.13.0:
  * This release includes more Neon and AVX2 optimizations, adds a
    new codec control to set per frame QP, upgrades GoogleTest to
    v1.12.1, and includes numerous bug fixes.
  * Upgrading:
  - This release is ABI incompatible with the previous release.
  - New codec control VP9E_SET_QUANTIZER_ONE_PASS to set per
    frame QP.
  - GoogleTest is upgraded to v1.12.1.
  - .clang-format is upgraded to clang-format-11.
  - VPX_EXT_RATECTRL_ABI_VERSION was bumped due to incompatible
    changes to the feature of using external rate control models
    for vp9.
  * Enhancement:
  - Numerous improvements on Neon optimizations.
  - Numerous improvements on AVX2 optimizations.
  - Additional ARM targets added for Visual Studio.
  * Bug fixes:
  - Fix to calculating internal stats when frame dropped.
  - Fix to segfault for external resize test in vp9.
  - Fix to build system with replacing egrep with grep -E.
  - Fix to a few bugs with external RTC rate control library.
  - Fix to make SVC work with VBR.
  - Fix to key frame setting in VP9 external RC.
  - Fix to -Wimplicit-int (Clang 16).
  - Fix to VP8 external RC for buffer levels.
  - Fix to VP8 external RC for dynamic update of layers.
  - Fix to VP9 auto level.
  - Fix to off-by-one error of max w/h in validate_config.
  - Fix to make SVC work for Profile 1.
- Bump sover define to 8 (and in baselibs.conf) following upstream
  changes.
* Fri Jul 22 2022 Dirk Müller <dmueller@suse.com>
- update to 1.12.0:
  This release adds optimizations for Loongarch, adds support for vp8 in the
  real-time rate control library, upgrades GoogleTest to v1.11.0, updates
  libwebm to libwebm-1.0.0.28-20-g206d268, and includes numerous bug fixes.
  - Enhancement:
    Numerous improvements on checking memory allocations.
    Optimizations for Loongarch.
    Code clean-up.
  - Bug fixes:
    Fix to a crash related to {vp8/vp9}_set_roi_map.
    Fix to compiling failure with -Wformat-nonliteral.
    Fix to integer overflow with vp9 with high resolution content.
    Fix to AddNoiseTest failure with ARMv7.
    Fix to libvpx Null-dereference READ in vp8.
* Wed Nov 24 2021 Callum Farmer <gmbr3@opensuse.org>
- Rename libvpx-configure-add-s390.patch to
  libvpx-configure-add-arch.patch: add support for RISC-V
* Fri Oct  8 2021 Callum Farmer <gmbr3@opensuse.org>
- update to 1.11.0:
  - Enhancement:
    Numerous improvements for Neon optimizations.
    Code clean-up and refactoring.
    Calculation of rd multiplier is changed with BDRATE gains.
  - Bug fixes:
    Fix to overflow on duration.
    Fix to several instances of -Wunused-but-set-variable.
    Fix to avoid chroma resampling for 420mpeg2 input.
    Fix to overflow in calc_iframe_target_size.
    Fix to disallow skipping transform and quantization.
    Fix some -Wsign-compare warnings in simple_encode.
    Fix input file path in simple_encode_test.
    Fix valid range for under/over_shoot pct.
  - Includes fix for CVE-2020-0034 (bsc#1166066)
- Remove libvpx-armv7-use-hard-float.patch: fixed
* Sat Oct  2 2021 Callum Farmer <gmbr3@opensuse.org>
- Enable PIC:
  * Remove libvpx-define-config_pic.patch
* Wed Apr 14 2021 Adrian Schröter <adrian@suse.de>
- using service/obspcio again because upstream tar ball is changing,
  leading to trust validation errors
* Tue Mar 30 2021 Dirk Müller <dmueller@suse.com>
- udpate to 1.10.0:
  This maintenance release adds support for darwin20 and new codec controls, as
  well as numerous bug fixes.
  - Upgrading:
    New codec control is added to disable loopfilter for VP9.
    New encoder control is added to disable feature to increase Q on overshoot
    detection for CBR.
    Configure support for darwin20 is added.
    New codec control is added for VP9 rate control. The control ID of this
    interface is VP9E_SET_EXTERNAL_RATE_CONTROL. To make VP9 use a customized
    external rate control model, users will have to implement each callback
    function in vpx_rc_funcs_t and register them using libvpx API
    vpx_codec_control_() with the control ID.
  - Enhancement:
    Use -std=gnu++11 instead of -std=c++11 for c++ files.
  - Bug fixes:
    Override assembler with --as option of configure for MSVS.
    Fix several compilation issues with gcc 4.8.5.
    Fix to resetting rate control for temporal layers.
    Fix to the rate control stats of SVC example encoder when number of spatial
    layers is 1.
    Fix to reusing motion vectors from the base spatial layer in SVC.
    2 pass related flags removed from SVC example encoder.
* Thu Aug  6 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.0
  This release adds support for NV12, a separate library for rate control, as
  well as incremental improvements.
  - Upgrading:
    NV12 support is added to this release.
    A new interface is added for VP9 rate control. The new library libvp9rc.a
    must be linked by applications.
    Googletest is updated to v1.10.0.
    simple_encode.cc is compiled into a new library libsimple_encode.a with
    CONFIG_RATE_CTRL.
  - Enhancement:
    Various changes to improve VP9 SVC, rate control, quality and speed to real
    time encoding.
  - Bug fixes:
    Fix key frame update refresh simulcast flexible svc.
    Fix to disable_16x16part speed feature for real time encoding.
    Fix some signed integer overflows for VP9 rate control.
    Fix initialization of delta_q_uv.
    Fix condition in regulate_q for cyclic refresh.
    Various fixes to dynamic resizing for VP9 SVC.
* Fri Jan 10 2020 Adrian Schröter <adrian@suse.de>
- Update to version 1.8.2:
  Fixes:
  - CVE-2019-2126 bsc#1160611: double free in ParseContentEncodingEntry()
  - CVE-2019-9325 bsc#1160612: out-of-bounds read
  - CVE-2019-9232 bsc#1160613: Fix OOB memory access on fuzzed data
  - CVE-2019-9433 bsc#1160614: use-after-free in vp8_deblock()
  - CVE-2019-9371 bsc#1160615: resource exhaustion after memory leak
  official changelog:
  * This release collects incremental improvements to many aspects of the library.
  * Upgrading:
    ARCH_* defines have been removed in favor of VPX_ARCH_*.
* Thu Jul 18 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.1:
  * This release collects incremental improvements to many aspects
    of the library.
  * Upgrading:
  - VP8E_SET_CPUUSED now accepts values up to 9 for vp9.
  - VPX_CTRL_VP9E_SET_MAX_INTER_BITRATE_PCT had a spelling fix
    (was VP8E).
  - The --sdk-path option has been removed. If you were using it
    to build for Android please read build/make/Android.mk for
    alternatives.
  - All PPC optimizations have been disabled:
    https://bugs.chromium.org/p/webm/issues/detail?id=1522.
  * Enhancements: Various changes to improve encoder rate control,
    quality and speed for practically every use case.
  * Bug fixes: vp9-rtc: Fix color artifacts for speed >= 8.
* Wed Apr 24 2019 Martin Liška <mliska@suse.cz>
- Disable LTO (boo#1133255).
* Mon Feb 11 2019 Adrian Schröter <adrian@suse.de>
- disable vsx on ppc64le to fix build failure
* Tue Feb  5 2019 Adrian Schröter <adrian@suse.de>
- update to version 1.8.0
  This release focused on encoding performance for realtime and VOD use cases.
  - Upgrading:
    This adds and improves several vp9 controls. Most are related to SVC:
    VP9E_SET_SVC_FRAME_DROP_LAYER:
  - Frame dropping in SVC.
    VP9E_SET_SVC_INTER_LAYER_PRED:
  - Inter-layer prediction in SVC.
    VP9E_SET_SVC_GF_TEMPORAL_REF:
  - Enable long term temporal reference in SVC.
    VP9E_SET_SVC_REF_FRAME_CONFIG/VP9E_GET_SVC_REF_FRAME_CONFIG:
  - Extend and improve this control for better flexibility in setting SVC
    pattern dynamically.
    VP9E_SET_POSTENCODE_DROP:
  - Allow for post-encode frame dropping (applies to non-SVC too).
    VP9E_SET_SVC_SPATIAL_LAYER_SYNC:
  - Enable spatial layer sync frames.
    VP9E_SET_SVC_LAYER_ID:
  - Extend api to specify temporal id for each spatial layers.
    VP9E_SET_ROI_MAP:
  - Extend Region of Interest functionality to VP9.
  - Enhancements:
    2 pass vp9 encoding has improved substantially. When using --auto-alt-ref=6,
    we see approximately 8%% for VBR and 10%% for CQ. When using --auto-alt-ref=1,
    the gains are approximately 4%% for VBR and 5%% for CQ.
    For real-time encoding, speed 7 has improved by ~5-10%%. Encodes targeted at
    screen sharing have improved when the content changes significantly (slide
    sharing) or scrolls. There is a new speed 9 setting for mobile devices which
    is about 10-20%% faster than speed 8.
  - Bug fixes:
    VP9 denoiser issue.
    VP9 partition issue for 1080p.
    VP9 rate control improvments.
    Postprocessing Multi Frame Quality Enhancement (MFQE) issue.
    VP8 multithread decoder issues.
    A variety of fuzzing issues.
- so name is changing to 6
- use optflags for building
* Tue Mar  6 2018 adrian@suse.de
- update to version 1.7.0
  This release focused on high bit depth performance (10/12 bit) and vp9
  encoding improvements.
  - Upgrading:
    This release is ABI incompatible due to new vp9 encoder features.
    Frame parallel decoding for vp9 has been removed.
  - Enhancements:
    vp9 encoding supports additional threads with --row-mt. This can be greater
    than the number of tiles.
    Two new vp9 encoder options have been added:
  - -corpus-complexity
  - -tune-content=film
    Additional tooling for respecting the vp9 "level" profiles has been added.
  - Bug fixes:
    A variety of fuzzing issues.
    vp8 threading fix for ARM.
    Codec control VP9_SET_SKIP_LOOP_FILTER fixed.
    Reject invalid multi resolution configurations.
- drop obsolete CVE-2017-13194.patch
- switch to git service since no tar ball at the old place anymore
- so name increase to 5
- use gnu99 for ppc
* Fri Mar  2 2018 idonmez@suse.com
- Enable VP9 10bit encoding support boo#1083537
* Thu Jan 18 2018 Adrian Schröter <adrian@suse.de>
- cleanup traces for testing, we don't have the >400MB test data here
* Thu Jan 18 2018 Adrian Schröter <adrian@suse.de>
- Fix OOB caused by odd frame width with patch from android
  Adding patch CVE-2017-13194.patch (CVE-2017-13194)
- this changelog entry also contains the new scheme with full name
  and "umlaut" to test which tools may break with it in our distro.
  Please track problems here: https://github.com/openSUSE/obs-build/pull/214
* Thu Aug 31 2017 adrian@suse.de
- limit maximum size to 8K Fulldome resolution to avoid
  DoS attacks. CVE-2017-0641 boo#1056539
* Fri Mar  3 2017 tchvatal@suse.com
- Version update to 1.6.1:
  * Improvements on the VP9 speed of encoding and decoding
  * Various fixes found by fuzzing
* Sun Jan  1 2017 jengelh@inai.de
- Summary updates
* Wed Sep  7 2016 tchvatal@suse.com
- Ensure the enable vp8 vp9 postproc and multithread are always on
- Enable verbose build
- Add switches to be able to build chromium:
  * --enable-experimental --enable-spatial-svc
* Fri Aug 12 2016 jengelh@inai.de
- Rename unfitting macro name "soname"; there is no SONAME here,
  just the version.
* Thu Aug 11 2016 olaf@aepfle.de
- Update to version 1.6.0
  This release improves upon the VP9 encoder and speeds up the encoding and
  decoding processes.
  - Enhancement:
    A core focus has been performance for low end Intel processors. SSSE3
    instructions such as 'pshufb' have been avoided and instructions have been
    reordered to better accommodate the more constrained pipelines.
    As a result, devices based on Celeron processors have seen substantial
    decoding improvements. From Indian Runner Duck to Javan Whistling Duck,
    decoding speed improved between 10 and 30%%. Between Javan Whistling Duck
    and Khaki Campbell Duck, it improved another 10 to 15%%.
    While Celeron benefited most, Core-i5 also improved 5%% and 10%% between the
    respective releases.
    Realtime performance for WebRTC for both speed and quality has received a
    lot of attention.
  - Bug Fixes:
    A number of fuzzing issues, found variously by Mozilla, Chromium and others,
    have been fixed and we strongly recommend updating.
- Remove libvpx-pkgconfig-version.patch
* Tue Jun 14 2016 adrian@suse.de
- Update to current upstream version to fix CVE-2016-2464 (boo#984448)
* Tue Mar 22 2016 olaf@aepfle.de
- Fix build in SLE_11 by disabling ssse3
- Fix vpc.pc version with libvpx-pkgconfig-version.patch
* Tue Mar 22 2016 adrian@suse.de
- Update to current upstream version to fix CVE-2016-1621 (bnc#972021)
- enable test suite during build
- From official Changelog:
  - Incompatible changes:
    The VP9 encoder's default keyframe interval changed to 128 from 9999.
- Drop libvpx-disable-cross-for-arm.patch
* Sat Dec 19 2015 joerg.lorenzen@ki.tng.de
- Update to version 1.5.0
  + This release improves upon the VP9 encoder and speeds up the
    encoding and decoding processes.
  + Upgrading:
    This release is ABI incompatible with 1.4.0. It drops deprecated
    VP8 controls and adds a variety of VP9 controls for testing.
    The vpxenc utility now prefers VP9 by default.
  + Enhancements:
    Faster VP9 encoding and decoding.
    Smaller library size by combining functions used by VP8 and VP9.
  + Bug Fixes:
    A variety of fuzzing issues.
- Fixed libvpx-configure-add-s390.patch and changed baselibs.conf
  to libvpx3.
- Removed uneeded servive file.
* Tue May 12 2015 joerg.lorenzen@ki.tng.de
- Update to version 1.4.0
  + This release includes significant improvements to the VP9 codec.
  + Upgrading:
    This release is ABI incompatible with 1.3.0. It drops the
    compatibility layer, requiring VPX_IMG_FMT_* instead of
    IMG_FMT_*, and adds several codec controls for VP9.
  + Enhancements:
    Faster VP9 encoding and decoding.
    Multithreaded VP9 decoding (tile and frame-based).
    Multithreaded VP9 encoding - on by default.
    YUV 4:2:2 and 4:4:4 support in VP9.
    10 and 12bit support in VP9.
    64bit ARM support by replacing ARM assembly with intrinsics.
  + Bug Fixes:
    Fixes a VP9 bitstream issue in Profile 1. This only affected
    non-YUV 4:2:0 files.
  + Known Issues:
    Frame Parallel decoding fails for segmented and non-420 files.
- Fixed all patches and changed baselibs.conf to libvpx2.
* Mon Feb 23 2015 idonmez@suse.com
- Add baselibs.conf as source
* Mon Feb 23 2015 rguenther@suse.com
- Build with -std=gnu89 to deal with GCC 5 defaulting to -std=gnu11
  and the C11 stddef.h providing a max_align_t that conflicts with
  the one provided by nestegg/halloc/src/align.h.
* Tue Dec 10 2013 hrvoje.senjan@gmail.com
- Update to version 1.3.0
  + This release is ABI and API compatible with Duclair (v1.0.0).
  + This release introduces the VP9 codec in a backward-compatible
    way. All existing users of VP8 can continue to use the library
    without modification. However, some VP8 options do not map to
    VP9 in the same manner.
  + Enhancements:
  - Get rid of bashisms in the main build scripts
  - Added usage info on command line options
  - Add lossless compression mode
  - Dll build of libvpx
  - Add additional Mac OS X targets: 10.7, 10.8 and 10.9
  - Add option to disable documentation
  - configure: add --enable-external-build support
  - make: support V=1 as short form of verbose=yes
  - configure: support mingw-w64
  - configure: support hardfloat armv7 CHOSTS
  - configure: add support for android x86
  - Add estimated completion time to vpxenc
  - Don't exit on decode errors in vpxenc
  - vpxenc: support scaling prior to encoding
  - vpxdec: support scaling output
  - vpxenc: improve progress indicators with --skip
  - msvs: Don't link to winmm.lib
  - Add a new script for producing vcxproj files
  - Produce Visual Studio 10 and 11 project files
  - Produce Windows Phone project files
  - msvs-build: use msbuild for vs >= 2005
  - configure: default configure log to config.log
  - Add encoding option --static-thresh
  + Speed:
  - Miscellaneous speed optimizations for VP8 and VP9.
  + Quality:
  - In general, quality is consistent with the Eider release.
  + Bug Fixes:
  - This release represents approximately a year of engineering
    effort, and contains multiple bug fixes. Please refer to git
    history for details.
- Rebase libvpx-armv7-use-hard-float.patch and
  libvpx-configure-add-s390.patch to this release
- Droped version_1.1.0_to_1.2.0.diff
- Added xz BuildRequires
- Remove Source URL, as the tarball is not available at that place
- Tarball is generated from v1.3.0 tag
* Mon Jan 28 2013 adrian@suse.de
- update to version 1.2.0
  - doing it via patch due to lacking release tar ball
- From release notes:
  - full api and abi compatible to 1.x release line
  - Enhancements:
    VP8 optimizations for MIPS dspr2
    vpxenc: add -quiet option
  - Speed:
    Encoder and decoder speed is consistent with the Eider release.
  - Quality:
    In general, quality is consistent with the Eider release.
    Minor tweaks to ARNR filtering
    Minor improvements to real time encoding with multiple temporal layers
  - Bug Fixes:
    Fixes multithreaded encoder race condition in loopfilter
    Fixes multi-resolution threaded encoding
    Fix potential encoder dead-lock after picture resize
* Mon Dec 10 2012 guillaume@opensuse.org
- Fix ARM builds
  + Removed old unused patch (libvpx-configure-add-armv7-tgt-isa.patch)
  + Add new patches for ARM:
  - libvpx-disable-cross-for-arm.patch: to fix toolchain names for ARM
  - libvpx-armv7-use-hard-float.patch: to fix float abi for armv7
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 1.1.0:
  + Enhancements:
  - Adds a motion compensated temporal denoiser to the encoder
  - support for new compilers and platforms were added
  - Changing resolution with vpx_codec_enc_config_set() is now
    supported
  + Improved performance
  + Bugs fixed
- Changes from version 1.0.0:
  + Enhancements:
  - This release introduces several substantial new features to
    the encoder, of particular interest to real time streaming
    applications.
  + Improved performance
  + Encoder quality in the single stream case is consistent with
    the Cayuga release.
  + Bug fixes
- Rename libvpx0 to libvpx1, following upstreams soname bump (also
  in baselibs.conf)
- Add pkg-config BuildRequires: as we provide a .pc file, we need
  pkg-config to be able to create the pkgconfig() provides
  (automatically).
- libvpx-configure-add-armv7-tgt-isa.patch currently disabled:
  needs more work.
* Tue Nov 29 2011 ro@suse.de
- make it build on s390/s390x
* Sat Oct 15 2011 jlee@suse.com
- support build libvpx on armv7hl architecture
  * add libvpx-configure-add-armv7-tgt-isa.patch
  * add armv7-linux-gcc target and enable runtime cpu detect when
    configure. It both support ARMv7 cpu with or without NEON.
    e.g. NVIDIA Tegra 2
* Wed Aug 24 2011 adrian@suse.de
- update to version 0.9.7 patchlevel 1
  * speed and quality optimizations (see CHANGELOG file)
  * bugfixes (see CHANGELOG file)
  * provides pkgconfig file
* Thu Apr 14 2011 toddrme2178@gmail.com
- added 32bit compatibility libraries
* Wed Mar  9 2011 adrian@suse.de
- update to version 0.9.6
  + speed and picture quality improvements
* Sat Feb 12 2011 dimstar@opensuse.org
- Use make_install instead of makeinstall: has the side effect of
  fixing Fedora builds.
* Wed Dec  1 2010 adrian@suse.de
- update to version 0.9.5, find details in CHANGES file
  + reworked command line utils
  + lib has general big speed and quality improvements
  + hardware acceleration via MMX and SSE is supported if available
  + bugfixes
* Mon Sep 13 2010 vuntz@opensuse.org
- Fix license tags: libvpx0 has no GPLv2+ code and should be BSD3c
  only. Update the other tags to mention BSD3c instead of
  "BSD-style license", which is something license.opensuse.org
  doesn't know.
* Tue Aug 24 2010 dimstar@opensuse.org
- Update to version 0.9.1:
  + Enhancements:
  - ivfenc/ivfdec now support YUV4MPEG2 input and pipe I/O
  - Speed optimizations
  + Bugfixes:
  - Rate control
  - Prevent out-of-bounds accesses on invalid data
  + Build system updates:
  - Detect toolchain to be used automatically for native builds
  - Support building shared libraries
  - Better autotools emulation (--prefix, --libdir, DESTDIR)
- Pass --enable-pic, enable-shared & --enable-debug to configure
- Split out libvpx0 according SLPP.
- Drop upstream.diff (merged)
- Rename buildfix.diff to libvpx-define-config_pic.patch and tag
  the patch line.
- clean spec-file (spec-cleaner).
* Fri Jun  4 2010 tittiatcoke@gmail.com
- Initial package
  * based on the latest svn snapshot
  * Included patch to fix build for openSUSE <= 11.2
